@@ -3,6 +3,7 @@ __author__ = 'sibirrer'
 from lenstronomy.LensModel.Profiles.base_profile import LensProfileBase
 from lenstronomy.LensModel.Profiles.cored_density import CoredDensity
 from lenstronomy.LensModel.Profiles.cored_density_2 import CoredDensity2
+from lenstronomy.LensModel.Profiles.cored_density_exp import CoredDensityExp
 from lenstronomy.LensModel.Profiles.convergence import Convergence
 
 __all__ = ['CoredDensityMST']
@@ -25,6 +26,8 @@ class CoredDensityMST(LensProfileBase):
             self._profile = CoredDensity()
         elif profile_type == 'CORED_DENSITY_2':
             self._profile = CoredDensity2()
+        elif profile_type == 'CORED_DENSITY_EXP':
+            self._profile = CoredDensityExp()
         else:
             raise ValueError('profile_type %s not supported for CoredDensityMST instance.' % profile_type)
         self._convergence = Convergence()
@@ -74,9 +77,9 @@ class CoredDensityMST(LensProfileBase):
         :param r_core: core radius of the cored density profile
         :param center_x: x-center of the profile
         :param center_y: y-center of the profile
-        :return: df/dxx, df/dyy, df/dxy
+        :return: df/dxx, df/dxy, df/dyx, df/dyy
         """
         kappa_ext = 1 - lambda_approx
-        f_xx_cd, f_yy_cd, f_xy_cd = self._profile.hessian(x, y, kappa_ext, r_core, center_x, center_y)
-        f_xx_ms, f_yy_ms, f_xy_ms = self._convergence.hessian(x, y, kappa_ext, center_x, center_y)
-        return f_xx_cd - f_xx_ms, f_yy_cd - f_yy_ms, f_xy_cd - f_xy_ms
+        f_xx_cd, f_xy_cd, f_yx_cd, f_yy_cd = self._profile.hessian(x, y, kappa_ext, r_core, center_x, center_y)
+        f_xx_ms, f_xy_ms, f_yx_ms, f_yy_ms = self._convergence.hessian(x, y, kappa_ext, center_x, center_y)
+        return f_xx_cd - f_xx_ms, f_xy_cd - f_xy_ms, f_yx_cd - f_yx_ms, f_yy_cd - f_yy_ms
