@@ -40,7 +40,7 @@ class SIS(LensProfileBase):
 
     def hessian(self, x, y, theta_E, center_x=0, center_y=0):
         """
-        returns Hessian matrix of function d^2f/dx^2, d^f/dy^2, d^2/dxdy
+        returns Hessian matrix of function d^2f/dx^2, d^2/dxdy, d^2/dydx, d^f/dy^2
         """
         x_shift = x - center_x
         y_shift = y - center_y
@@ -56,7 +56,7 @@ class SIS(LensProfileBase):
         f_xx = y_shift*y_shift * prefac
         f_yy = x_shift*x_shift * prefac
         f_xy = -x_shift*y_shift * prefac
-        return f_xx, f_yy, f_xy
+        return f_xx, f_xy, f_xy, f_yy
 
     @staticmethod
     def rho2theta(rho0):
