@@ -1,5 +1,7 @@
 import numpy as np
 import lenstronomy.Util.util as util
+from skimage.measure import find_contours
+from lenstronomy.Util.magnification_finite_util import setup_mag_finite
 
 __all__ = ['LensModelExtensions']
 
@@ -9,8 +11,8 @@ class LensModelExtensions(object):
     class with extension routines not part of the LensModel core routines
     """
     def __init__(self, lensModel):
-        """
 
+        """
         :param lensModel: instance of the LensModel() class, or with same functionalities.
         In particular, the following definitions are required to execute all functionalities presented in this class:
         def ray_shooting()
@@ -22,8 +24,177 @@ class LensModelExtensions(object):
         """
         self._lensModel = lensModel
 
+    def magnification_finite_adaptive(self, x_image, y_image, source_x, source_y, kwargs_lens,
+                                      source_fwhm_parsec, z_source,
+                                      cosmo=None, grid_resolution=None,
+                                      grid_radius_arcsec=None, axis_ratio=0.5,
+                                      tol=0.001, step_size=0.05,
+                                      use_largest_eigenvalue=True,
+                                      source_light_model='SINGLE_GAUSSIAN',
+                                      dx=None, dy=None, size_scale=None, amp_scale=None,
+                                      fixed_aperture_size=False):
+        """
+        This method computes image magnifications with a finite-size background source assuming a Gaussian or a
+        double Gaussian source light profile. It can be much faster that magnification_finite for lens models with many
+        deflectors and a compact source. This is because most pixels in a rectangular window around a lensed
+        image of a compact source do not map onto the source, and therefore don't contribute to the integrated flux in
+        the image plane.
+
+        Rather than ray tracing through a rectangular grid, this routine accelerates the computation of image
+        magnifications with finite-size sources by ray tracing through an elliptical region oriented such that
+        tracks the surface brightness of the lensed image. The aperture size is initially quite small,
+        and increases in size until the flux inside of it (and hence the magnification) converges. The orientation of
+        the elliptical aperture is computed from the magnification tensor evaluated at the image coordinate.
+
+        If for whatever reason you prefer a circular aperture to the elliptical approximation using the hessian
+        eigenvectors, you can just set axis_ratio = 1.
+
+        To use the eigenvalues of the hessian matrix to estimate the optimum axis ratio, set axis_ratio = 0.
+
+        The default settings for the grid resolution and ray tracing window size work well for sources with fwhm between
+        0.5 - 100 pc.
+
+        :param x_image: a list or array of x coordinates [units arcsec]
+        :param y_image: a list or array of y coordinates [units arcsec]
+        :param kwargs_lens: keyword arguments for the lens model
+        :param source_fwhm_parsec: the size of the background source [units parsec]
+        :param z_source: the source redshift
+        :param cosmo: (optional) an instance of astropy.cosmology; if not specified, a default cosmology will be used
+        :param grid_resolution: the grid resolution in units arcsec/pixel; if not specified, an appropriate value will
+         be estimated from the source size
+        :param grid_radius_arcsec: (optional) the size of the ray tracing region in arcsec; if not specified, an appropriate value
+         will be estimated from the source size
+        :param axis_ratio: the axis ratio of the ellipse used for ray tracing; if axis_ratio = 0, then the eigenvalues
+         the hessian matrix will be used to estimate an appropriate axis ratio. Be warned: if the image is highly
+         magnified it will tend to curve out of the resulting ellipse
+        :param tol: tolerance for convergence in the magnification
+        :param step_size: sets the increment for the successively larger ray tracing windows
+        :param use_largest_eigenvalue: bool; if True, then the major axis of the ray tracing ellipse region
+         will be aligned with the eigenvector corresponding to the largest eigenvalue of the hessian matrix
+        :param source_light_model: the model for backgourn source light; currently implemented are 'SINGLE_GAUSSIAN' and
+         'DOUBLE_GAUSSIAN'.
+        :param dx: used with source model 'DOUBLE_GAUSSIAN', the offset of the second source light profile from the first
+         [arcsec]
+        :param dy: used with source model 'DOUBLE_GAUSSIAN', the offset of the second source light profile from the first
+         [arcsec]
+        :param size_scale: used with source model 'DOUBLE_GAUSSIAN', the size of the second source light profile relative
+         to the first
+        :param amp_scale: used with source model 'DOUBLE_GAUSSIAN', the peak brightness of the second source light profile
+         relative to the first
+        :param fixed_aperture_size: bool, if True the flux is computed inside a fixed aperture size with radius
+         grid_radius_arcsec
+        :return: an array of image magnifications
+        """
+
+        grid_x_0, grid_y_0, source_model, kwargs_source, grid_resolution, grid_radius_arcsec = setup_mag_finite(cosmo,
+                                                                                                                self._lensModel,
+                                                                                                                grid_radius_arcsec,
+                                                                                                                grid_resolution,
+                                                                                                                source_fwhm_parsec,
+                                                                                                                source_light_model,
+                                                                                                                z_source,
+                                                                                                                source_x,
+                                                                                                                source_y,
+                                                                                                                dx, dy,
+                                                                                                                amp_scale,
+                                                                                                                size_scale)
+        grid_x_0, grid_y_0 = grid_x_0.ravel(), grid_y_0.ravel()
+
+        minimum_magnification = 1e-5
+
+        magnifications = []
+
+        for xi, yi in zip(x_image, y_image):
+
+            w1, w2, v11, v12, v21, v22 = self.hessian_eigenvectors(xi, yi, kwargs_lens)
+            _v = [np.array([v11, v12]), np.array([v21, v22])]
+            _w = [abs(w1), abs(w2)]
+            if use_largest_eigenvalue:
+                idx = int(np.argmax(_w))
+            else:
+                idx = int(np.argmin(_w))
+            v = _v[idx]
+
+            rotation_angle = np.arctan(v[1] / v[0]) - np.pi / 2
+            grid_x, grid_y = util.rotate(grid_x_0, grid_y_0, rotation_angle)
+
+            if axis_ratio == 0:
+                sort = np.argsort(_w)
+                q = _w[sort[0]] / _w[sort[1]]
+                grid_r = np.hypot(grid_x, grid_y / q).ravel()
+            else:
+                grid_r = np.hypot(grid_x, grid_y / axis_ratio).ravel()
+
+            flux_array = np.zeros_like(grid_x_0)
+            step = step_size * grid_radius_arcsec
+
+            r_min = 0
+            if fixed_aperture_size:
+                r_max = grid_radius_arcsec
+            else:
+                r_max = step
+            magnification_current = 0.
+
+            while True:
+
+                flux_array = self._magnification_adaptive_iteration(flux_array, xi, yi, grid_x_0, grid_y_0, grid_r,
+                                                                    r_min, r_max, self._lensModel, kwargs_lens,
+                                                                    source_model, kwargs_source)
+                new_magnification = np.sum(flux_array) * grid_resolution ** 2
+                diff = abs(new_magnification - magnification_current) / new_magnification
+
+                if r_max >= grid_radius_arcsec:
+                    break
+                elif diff < tol and new_magnification > minimum_magnification:
+                    break
+                else:
+                    r_min += step
+                    r_max += step
+                    magnification_current = new_magnification
+
+            magnifications.append(new_magnification)
+
+        return np.array(magnifications)
+
+    @staticmethod
+    def _magnification_adaptive_iteration(flux_array, x_image, y_image, grid_x, grid_y, grid_r, r_min, r_max,
+                                          lensModel, kwargs_lens, source_model, kwargs_source):
+        """
+        This function computes the surface brightness of coordinates in 'flux_array' that satisfy r_min < grid_r < r_max,
+        where each coordinate in grid_r corresponds to a certain entry in flux_array. Likewise, grid_x, and grid_y
+
+        :param flux_array: an array that contains the flux in each pixel
+        :param x_image: image x coordinate
+        :param y_image: image y coordinate
+        :param grid_x: an array of x coordinates
+        :param grid_y: an array of y coordinates
+        :param grid_r: an array of projected distances from the origin
+        :param r_min: sets the inner radius of the annulus where ray tracing happens
+        :param r_max: sets the outer radius of the annulus where ray tracing happens
+        :param lensModel: an instance of LensModel
+        :param kwargs_lens: keywords for the lens model
+        :param source_model: an instance of LightModel
+        :param kwargs_source: keywords for the light model
+        :return: the flux array where the surface brightness has been computed for all pixels
+        with r_min < grid_r < r_max.
+        """
+
+        condition1 = grid_r >= r_min
+        condition2 = grid_r < r_max
+        condition = np.logical_and(condition1, condition2)
+
+        inds = np.where(condition)[0]
+
+        xcoords = grid_x[inds] + x_image
+        ycoords = grid_y[inds] + y_image
+        beta_x, beta_y = lensModel.ray_shooting(xcoords, ycoords, kwargs_lens)
+        flux_in_pixels = source_model.surface_brightness(beta_x, beta_y, kwargs_source)
+        flux_array[inds] = flux_in_pixels
+
+        return flux_array
+
     def magnification_finite(self, x_pos, y_pos, kwargs_lens, source_sigma=0.003, window_size=0.1, grid_number=100,
-                             shape="GAUSSIAN", polar_grid=False, aspect_ratio=0.5):
+                             polar_grid=False, aspect_ratio=0.5):
         """
         returns the magnification of an extended source with Gaussian light profile
         :param x_pos: x-axis positons of point sources
@@ -31,19 +202,14 @@ class LensModelExtensions(object):
         :param kwargs_lens: lens model kwargs
         :param source_sigma: Gaussian sigma in arc sec in source
         :param window_size: size of window to compute the finite flux
-        :param grid_number: number of grid cells per axis in the window to numerically comute the flux
+        :param grid_number: number of grid cells per axis in the window to numerically compute the flux
         :return: numerically computed brightness of the sources
         """
 
         mag_finite = np.zeros_like(x_pos)
         deltaPix = float(window_size)/grid_number
-        if shape == 'GAUSSIAN':
-            from lenstronomy.LightModel.Profiles.gaussian import Gaussian
-            quasar = Gaussian()
-        elif shape == 'TORUS':
-            import lenstronomy.LightModel.Profiles.ellipsoid as quasar
-        else:
-            raise ValueError("shape %s not valid for finite magnification computation!" % shape)
+        from lenstronomy.LightModel.Profiles.gaussian import Gaussian
+        quasar = Gaussian()
         x_grid, y_grid = util.make_grid(numPix=grid_number, deltapix=deltaPix, subgrid_res=1)
 
         if polar_grid is True:
@@ -189,20 +355,16 @@ class LensModelExtensions(object):
         ra_caustic_list = []
         dec_caustic_list = []
 
-        import matplotlib.pyplot as plt
-        cs = plt.contour(util.array2image(x_grid_high_res), util.array2image(y_grid_high_res), mag_high_res, [0],
-                         alpha=0.0)
-        paths = cs.collections[0].get_paths()
-        for i, p in enumerate(paths):
-            v = p.vertices
-            ra_points = v[:, 0]
-            dec_points = v[:, 1]
+        paths = find_contours(1/mag_high_res, 0.)
+        for i, v in enumerate(paths):
+            # x, y changed because of skimage conventions
+            ra_points = v[:, 1] * grid_scale - grid_scale * (numPix-1)/2
+            dec_points = v[:, 0] * grid_scale - grid_scale * (numPix-1)/2
             ra_crit_list.append(ra_points)
             dec_crit_list.append(dec_points)
             ra_caustics, dec_caustics = self._lensModel.ray_shooting(ra_points, dec_points, kwargs_lens)
             ra_caustic_list.append(ra_caustics)
             dec_caustic_list.append(dec_caustics)
-        plt.cla()
         return ra_crit_list, dec_crit_list, ra_caustic_list, dec_caustic_list
 
     def hessian_eigenvectors(self, x, y, kwargs_lens, diff=None):
@@ -359,21 +521,23 @@ class LensModelExtensions(object):
 
         return lambda_rad, lambda_tan, orientation_angle, dlambda_tan_dtan, dlambda_tan_drad, dlambda_rad_drad, dlambda_rad_dtan, dphi_tan_dtan, dphi_tan_drad, dphi_rad_drad, dphi_rad_dtan
 
-    def curved_arc_estimate(self, x, y, kwargs_lens, smoothing=None, smoothing_3rd=0.001):
+    def curved_arc_estimate(self, x, y, kwargs_lens, smoothing=None, smoothing_3rd=0.001, tan_diff=False):
         """
         performs the estimation of the curved arc description at a particular position of an arbitrary lens profile
 
         :param x: float, x-position where the estimate is provided
         :param y: float, y-position where the estimate is provided
         :param kwargs_lens: lens model keyword arguments
+        :param smoothing: (optional) finite differential of second derivative (radial and tangential stretches)
+        :param smoothing_3rd: differential scale for third derivative to estimate the tangential curvature
+        :param tan_diff: boolean, if True, also returns the relative tangential stretch differential in tangential direction
         :return: keyword argument list corresponding to a CURVED_ARC profile at (x, y) given the initial lens model
         """
         radial_stretch, tangential_stretch, v_rad1, v_rad2, v_tang1, v_tang2 = self.radial_tangential_stretch(x, y, kwargs_lens, diff=smoothing)
         dx_tang = x + smoothing_3rd * v_tang1
         dy_tang = y + smoothing_3rd * v_tang2
-        rad_dt, tang_dt, v_rad1_dt, v_rad2_dt, v_tang1_dt, v_tang2_dt = self.radial_tangential_stretch(dx_tang, dy_tang,
-                                                                                                       kwargs_lens,
-                                                                                                       diff=smoothing)
+        _, _, _, _, v_tang1_dt, v_tang2_dt = self.radial_tangential_stretch(dx_tang, dy_tang,kwargs_lens,
+                                                                            diff=smoothing)
         d_tang1 = v_tang1_dt - v_tang1
         d_tang2 = v_tang2_dt - v_tang2
         delta = np.sqrt(d_tang1**2 + d_tang2**2)
@@ -383,10 +547,34 @@ class LensModelExtensions(object):
             delta = np.sqrt(d_tang1 ** 2 + d_tang2 ** 2)
         curvature = delta / smoothing_3rd
         direction = np.arctan2(v_rad2 * np.sign(v_rad1 * x + v_rad2 * y), v_rad1 * np.sign(v_rad1 * x + v_rad2 * y))
-        #direction = np.arctan2(v_rad2, v_rad1)
+
         kwargs_arc = {'radial_stretch': radial_stretch,
                       'tangential_stretch': tangential_stretch,
                       'curvature': curvature,
                       'direction': direction,
                       'center_x': x, 'center_y': y}
+        if tan_diff:
+            lambda_rad, lambda_tan, orientation_angle, dlambda_tan_dtan, dlambda_tan_drad, dlambda_rad_drad, dlambda_rad_dtan, dphi_tan_dtan, dphi_tan_drad, dphi_rad_drad, dphi_rad_dtan = self.radial_tangential_differentials(x, y, kwargs_lens, center_x=0, center_y=0, smoothing_3rd=smoothing_3rd)
+            kwargs_arc['dtan_dtan'] = dlambda_tan_dtan / lambda_tan
         return kwargs_arc
+
+    def tangential_average(self, x, y, kwargs_lens, dr, smoothing=None, num_average=9):
+        """
+        computes average tangential stretch around position (x, y) within dr in radial direction
+
+        :param x: x-position (float)
+        :param y: y-position (float)
+        :param kwargs_lens: lens model keyword argument list
+        :param dr: averaging scale in radial direction
+        :param smoothing: smoothing scale of derivative
+        :param num_average: integer, number of points averaged over within dr in the radial direction
+        :return:
+        """
+        radial_stretch, tangential_stretch, v_rad1, v_rad2, v_tang1, v_tang2 = self.radial_tangential_stretch(x, y,
+                                                                                                              kwargs_lens,
+                                                                                                              diff=smoothing)
+        dr_array = np.linspace(start=-dr/2., stop=dr/2., num=num_average)
+        dx_r = x + dr_array * v_rad1
+        dy_r = y + dr_array * v_rad2
+        _, tangential_stretch_dr, _, _, _, _ = self.radial_tangential_stretch(dx_r, dy_r, kwargs_lens, diff=smoothing)
+        return np.average(tangential_stretch_dr)
