@@ -3,16 +3,19 @@ from lenstronomy.Util.util import convert_bool_list
 __all__ = ['ProfileListBase']
 
 
-_SUPPORTED_MODELS = ['SHIFT', 'NIE_POTENTIAL', 'CONST_MAG', 'SHEAR', 'SHEAR_GAMMA_PSI', 'CONVERGENCE', 'FLEXION',
+_SUPPORTED_MODELS = ['SHIFT', 'NIE_POTENTIAL', 'CONST_MAG', 'SHEAR', 'SHEAR_GAMMA_PSI', 'SHEAR_REDUCED', 'CONVERGENCE', 'FLEXION',
                      'FLEXIONFG', 'POINT_MASS', 'SIS', 'SIS_TRUNCATED', 'SIE', 'SPP', 'NIE', 'NIE_SIMPLE', 'CHAMELEON',
-                     'DOUBLE_CHAMELEON', 'TRIPLE_CHAMELEON', 'SPEP', 'PEMD', 'SPEMD', 'EPL', 'NFW', 'NFW_ELLIPSE',
+                     'DOUBLE_CHAMELEON', 'TRIPLE_CHAMELEON', 'SPEP', 'PEMD', 'SPEMD', 'EPL', 'EPL_NUMBA', 'SPL_CORE', 'NFW', 'NFW_ELLIPSE',
                      'NFW_ELLIPSE_GAUSS_DEC', 'TNFW', 'CNFW', 'CNFW_ELLIPSE', 'CTNFW_GAUSS_DEC', 'NFW_MC', 'SERSIC',
                      'SERSIC_ELLIPSE_POTENTIAL', 'SERSIC_ELLIPSE_KAPPA', 'SERSIC_ELLIPSE_GAUSS_DEC', 'PJAFFE',
                      'PJAFFE_ELLIPSE', 'HERNQUIST', 'HERNQUIST_ELLIPSE', 'GAUSSIAN', 'GAUSSIAN_KAPPA',
                      'GAUSSIAN_ELLIPSE_KAPPA', 'GAUSSIAN_ELLIPSE_POTENTIAL', 'MULTI_GAUSSIAN_KAPPA',
                      'MULTI_GAUSSIAN_KAPPA_ELLIPSE', 'INTERPOL', 'INTERPOL_SCALED', 'SHAPELETS_POLAR', 'SHAPELETS_CART',
-                     'DIPOLE', 'CURVED_ARC', 'ARC_PERT', 'coreBURKERT', 'CORED_DENSITY', 'CORED_DENSITY_2',
-                     'CORED_DENSITY_MST', 'CORED_DENSITY_2_MST', 'NumericalAlpha', 'MULTIPOLE', 'HESSIAN']
+                     'DIPOLE', 'CURVED_ARC_CONST', 'CURVED_ARC_SPP', 'CURVED_ARC_SIS_MST', 'CURVED_ARC_SPT',
+                     'CURVED_ARC_TAN_DIFF', 'ARC_PERT', 'coreBURKERT',
+                     'CORED_DENSITY', 'CORED_DENSITY_2', 'CORED_DENSITY_MST', 'CORED_DENSITY_2_MST', 'CORED_DENSITY_EXP',
+                     'CORED_DENSITY_EXP_MST', 'NumericalAlpha', 'MULTIPOLE', 'HESSIAN', 'ElliSLICE', 'ULDM']
+
 
 class ProfileListBase(object):
     """
@@ -66,7 +69,7 @@ class ProfileListBase(object):
         """
 
         if lens_type == 'SHIFT':
-            from lenstronomy.LensModel.Profiles.alpha_shift import Shift
+            from lenstronomy.LensModel.Profiles.constant_shift import Shift
             return Shift()
         elif lens_type == 'NIE_POTENTIAL':
             from lenstronomy.LensModel.Profiles.nie_potential import NIE_POTENTIAL
@@ -80,6 +83,9 @@ class ProfileListBase(object):
         elif lens_type == 'SHEAR_GAMMA_PSI':
             from lenstronomy.LensModel.Profiles.shear import ShearGammaPsi
             return ShearGammaPsi()
+        elif lens_type == 'SHEAR_REDUCED':
+            from lenstronomy.LensModel.Profiles.shear import ShearReduced
+            return ShearReduced()
         elif lens_type == 'CONVERGENCE':
             from lenstronomy.LensModel.Profiles.convergence import Convergence
             return Convergence()
@@ -134,6 +140,12 @@ class ProfileListBase(object):
         elif lens_type == 'EPL':
             from lenstronomy.LensModel.Profiles.epl import EPL
             return EPL()
+        elif lens_type == 'EPL_NUMBA':
+            from lenstronomy.LensModel.Profiles.epl_numba import EPL_numba
+            return EPL_numba()
+        elif lens_type == 'SPL_CORE':
+            from lenstronomy.LensModel.Profiles.splcore import SPLCORE
+            return SPLCORE()
         elif lens_type == 'NFW':
             from lenstronomy.LensModel.Profiles.nfw import NFW
             return NFW()
@@ -215,9 +227,24 @@ class ProfileListBase(object):
         elif lens_type == 'DIPOLE':
             from lenstronomy.LensModel.Profiles.dipole import Dipole
             return Dipole()
-        elif lens_type == 'CURVED_ARC':
-            from lenstronomy.LensModel.Profiles.curved_arc import CurvedArc
-            return CurvedArc()
+        elif lens_type == 'CURVED_ARC_CONST':
+            from lenstronomy.LensModel.Profiles.curved_arc_const import CurvedArcConst
+            return CurvedArcConst()
+        elif lens_type == 'CURVED_ARC_CONST_MST':
+            from lenstronomy.LensModel.Profiles.curved_arc_const import CurvedArcConstMST
+            return CurvedArcConstMST()
+        elif lens_type == 'CURVED_ARC_SPP':
+            from lenstronomy.LensModel.Profiles.curved_arc_spp import CurvedArcSPP
+            return CurvedArcSPP()
+        elif lens_type == 'CURVED_ARC_SIS_MST':
+            from lenstronomy.LensModel.Profiles.curved_arc_sis_mst import CurvedArcSISMST
+            return CurvedArcSISMST()
+        elif lens_type == 'CURVED_ARC_SPT':
+            from lenstronomy.LensModel.Profiles.curved_arc_spt import CurvedArcSPT
+            return CurvedArcSPT()
+        elif lens_type == 'CURVED_ARC_TAN_DIFF':
+            from lenstronomy.LensModel.Profiles.curved_arc_tan_diff import CurvedArcTanDiff
+            return CurvedArcTanDiff()
         elif lens_type == 'ARC_PERT':
             from lenstronomy.LensModel.Profiles.arc_perturbations import ArcPerturbations
             return ArcPerturbations()
@@ -230,18 +257,30 @@ class ProfileListBase(object):
         elif lens_type == 'CORED_DENSITY_2':
             from lenstronomy.LensModel.Profiles.cored_density_2 import CoredDensity2
             return CoredDensity2()
+        elif lens_type == 'CORED_DENSITY_EXP':
+            from lenstronomy.LensModel.Profiles.cored_density_exp import CoredDensityExp
+            return CoredDensityExp()
         elif lens_type == 'CORED_DENSITY_MST':
             from lenstronomy.LensModel.Profiles.cored_density_mst import CoredDensityMST
             return CoredDensityMST(profile_type='CORED_DENSITY')
         elif lens_type == 'CORED_DENSITY_2_MST':
             from lenstronomy.LensModel.Profiles.cored_density_mst import CoredDensityMST
             return CoredDensityMST(profile_type='CORED_DENSITY_2')
+        elif lens_type == 'CORED_DENSITY_EXP_MST':
+            from lenstronomy.LensModel.Profiles.cored_density_mst import CoredDensityMST
+            return CoredDensityMST(profile_type='CORED_DENSITY_EXP')
         elif lens_type == 'NumericalAlpha':
             from lenstronomy.LensModel.Profiles.numerical_deflections import NumericalAlpha
             return NumericalAlpha(custom_class)
         elif lens_type == 'MULTIPOLE':
             from lenstronomy.LensModel.Profiles.multipole import Multipole
             return Multipole()
+        elif lens_type == 'ElliSLICE':
+            from lenstronomy.LensModel.Profiles.elliptical_density_slice import ElliSLICE
+            return ElliSLICE()
+        elif lens_type == 'ULDM':
+            from lenstronomy.LensModel.Profiles.uldm import Uldm
+            return Uldm()
         else:
             raise ValueError('%s is not a valid lens model. Supported are: %s.' % (lens_type, _SUPPORTED_MODELS))
 
