@@ -1,10 +1,19 @@
 __author__ = 'sibirrer'
 
-#this file contains a class which describes the surface brightness of the light models
+# this file contains a class which describes the surface brightness of the light models
 
 import numpy as np
 from lenstronomy.Util.util import convert_bool_list
 
+__all__ = ['LightModelBase']
+
+
+_MODELS_SUPPORTED = ['GAUSSIAN', 'GAUSSIAN_ELLIPSE', 'ELLIPSOID', 'MULTI_GAUSSIAN', 'MULTI_GAUSSIAN_ELLIPSE',
+                     'SERSIC', 'SERSIC_ELLIPSE', 'CORE_SERSIC', 'SHAPELETS', 'SHAPELETS_POLAR', 'SHAPELETS_POLAR_EXP',
+                     'HERNQUIST', 'HERNQUIST_ELLIPSE', 'PJAFFE', 'PJAFFE_ELLIPSE', 'UNIFORM', 'POWER_LAW', 'NIE',
+                     'CHAMELEON', 'DOUBLE_CHAMELEON', 'TRIPLE_CHAMELEON', 'INTERPOL', 'SLIT_STARLETS',
+                     'SLIT_STARLETS_GEN2']
+
 
 class LightModelBase(object):
     """
@@ -92,7 +101,7 @@ class LightModelBase(object):
                 from lenstronomy.LightModel.Profiles.starlets import SLIT_Starlets
                 self.func_list.append(SLIT_Starlets(second_gen=True))
             else:
-                raise ValueError('Warning! No light model of type', profile_type, ' found!')
+                raise ValueError('No light model of type %s found! Supported are the following models: %s' % (profile_type, _MODELS_SUPPORTED))
         self._num_func = len(self.func_list)
 
     def surface_brightness(self, x, y, kwargs_list, k=None):
@@ -136,7 +145,8 @@ class LightModelBase(object):
     def total_flux(self, kwargs_list, norm=False, k=None):
         """
         Computes the total flux of each individual light profile. This allows to estimate the total flux as
-        well as lenstronomy amp to magnitude conversions. Not all models are supported
+        well as lenstronomy amp to magnitude conversions. Not all models are supported.
+        The units are linked to the data to be modelled with associated noise properties (default is count/s).
 
         :param kwargs_list: list of keyword arguments corresponding to the light profiles. The 'amp' parameter can be missing.
         :param norm: bool, if True, computes the flux for amp=1
