@@ -1,6 +1,7 @@
 import numpy as np
 import math
-from corner.corner import quantile
+from corner import quantile
+import matplotlib.pyplot as plt
 
 from lenstronomy.Util.package_util import exporter
 export, __all__ = exporter()
@@ -40,8 +41,8 @@ def sqrt(inputArray, scale_min=None, scale_max=None):
 @export
 def text_description(ax, d, text, color='w', backgroundcolor='k',
                      flipped=False, font_size=15):
-    c_vertical = font_size / 10.**2
-    c_horizontal = 1./20
+    c_vertical = 1/15. #+ font_size / d / 10.**2
+    c_horizontal = 1./30
     if flipped:
         ax.text(d - d * c_horizontal, d - d * c_vertical, text, color=color,
                 fontsize=font_size,
@@ -88,19 +89,39 @@ def coordinate_arrows(ax, d, coords, color='w', font_size=15, arrow_size=0.05):
 
 
 @export
-def plot_line_set(ax, coords, ra_caustic_list, dec_caustic_list, shift=0., color='g'):
+def plot_line_set_list(ax, coords, line_set_list_x, line_set_list_y, shift=0., color='g'):
     """
 
-    :param coords:
-    :return:
+    :param coords: Coordinates() class instance
+    :param line_set_list_x: list of numpy arrays corresponding of different disconnected regions of the line
+     (e.g. caustic or critical curve)
+    :param line_set_list_y: list of numpy arrays corresponding of different disconnected regions of the line
+     (e.g. caustic or critical curve)
+    :return: plot with line sets on matplotlib axis
     """
     deltaPix = coords.pixel_width
-    #for i in range(len(ra_caustic_list)):
-    x_c, y_c = coords.map_coord2pix(ra_caustic_list, dec_caustic_list)
-    ax.plot((x_c + 0.5) * (deltaPix) - shift, (y_c + 0.5) * (deltaPix) - shift, ',', color=color)
+    for i in range(len(line_set_list_x)):
+        x_c, y_c = coords.map_coord2pix(line_set_list_x[i], line_set_list_y[i])
+        ax.plot((x_c + 0.5) * (deltaPix) - shift, (y_c + 0.5) * (deltaPix) - shift, ',', color=color)
     return ax
 
 
+@export
+def plot_line_set(ax, coords, line_set_list_x, line_set_list_y, shift=0., color='g'):
+    """
+
+    :param coords: Coordinates() class instance
+    :param line_set_list_x: numpy arrays corresponding of different disconnected regions of the line
+     (e.g. caustic or critical curve)
+    :param line_set_list_y: numpy arrays corresponding of different disconnected regions of the line
+     (e.g. caustic or critical curve)
+    :return: plot with line sets on matplotlib axis
+    """
+    deltaPix = coords.pixel_width
+    x_c, y_c = coords.map_coord2pix(line_set_list_x, line_set_list_y)
+    ax.plot((x_c + 0.5) * (deltaPix) - shift, (y_c + 0.5) * (deltaPix) - shift, ',', color=color)
+    return ax
+
 @export
 def image_position_plot(ax, coords, ra_image, dec_image, color='w', image_name_list=None):
     """
@@ -161,3 +182,20 @@ def result_string(x, weights=None, title_fmt=".2f", label=None):
     if label is not None:
         title = "{0} = {1}".format(label, title)
     return title
+
+
+@export
+def cmap_conf(cmap_string):
+    """
+    configures matplotlib color map
+
+    :param cmap_string: string of cmap name, or cmap instance
+    :return: cmap instance with setting for bad pixels and values below the threshold
+    """
+    if isinstance(cmap_string, str):
+        cmap = plt.get_cmap(cmap_string)
+    else:
+        cmap = cmap_string
+    cmap.set_bad(color='k', alpha=1.)
+    cmap.set_under('k')
+    return cmap
