@@ -1,6 +1,6 @@
 import numpy as np
 import copy
-from lenstronomy.PointSource.point_source_types import PointSourceCached
+from lenstronomy.PointSource.point_source_cached import PointSourceCached
 
 __all__ = ['PointSource']
 
@@ -13,26 +13,27 @@ class PointSource(object):
                  additional_images_list=None, flux_from_point_source_list=None, magnification_limit=None,
                  save_cache=False, kwargs_lens_eqn_solver=None):
         """
-        min_distance=0.05, search_window=5, precision_limit=10**(-10), num_iter_max=100,
-                 x_center=0, y_center=0):
+
         :param point_source_type_list: list of point source types
         :param lensModel: instance of the LensModel() class
-        :param fixed_magnification_list: list of bools (same length as point_source_type_list). If True, magnification
+        :param fixed_magnification_list: list of booleans (same length as point_source_type_list). If True, magnification
         ratio of point sources is fixed to the one given by the lens model
-        :param additional_images_list: list of bools (same length as point_source_type_list). If True, search for
+        :param additional_images_list: list of booleans (same length as point_source_type_list). If True, search for
         additional images of the same source is conducted.
-        :param flux_from_point_source_list: list of bools (optional), if set, will only return image positions
+        :param flux_from_point_source_list: list of booleans (optional), if set, will only return image positions
          (for imaging modeling) for the subset of the point source lists that =True. This option enables to model
+         imaging data with transient point sources, when the point source positions are measured and present at a
+         different time than the imaging data
         :param magnification_limit: float >0 or None, if float is set and additional images are computed, only those
          images will be computed that exceed the lensing magnification (absolute value) limit
         :param save_cache: bool, saves image positions and only if delete_cache is executed, a new solution of the lens
-         equation is conducted with the lens model parameters provided. This can increase the speed as multiple times the
-         image positions are requested for the same lens model. Attention in usage!
+         equation is conducted with the lens model parameters provided. This can increase the speed as multiple times
+         the image positions are requested for the same lens model. Attention in usage!
         :param kwargs_lens_eqn_solver: keyword arguments specifying the numerical settings for the lens equation solver
          see LensEquationSolver() class for details
 
-        for the parameters: min_distance=0.01, search_window=5, precision_limit=10**(-10), num_iter_max=100
-        have a look at the lensEquationSolver class
+        for the kwargs_lens_eqn_solver parameters: have a look at the lensEquationSolver class, such as:
+        min_distance=0.01, search_window=5, precision_limit=10**(-10), num_iter_max=100
 
         """
         self._lensModel = lensModel
@@ -48,14 +49,14 @@ class PointSource(object):
         self._flux_from_point_source_list = flux_from_point_source_list
         for i, model in enumerate(point_source_type_list):
             if model == 'UNLENSED':
-                from lenstronomy.PointSource.point_source_types import Unlensed
+                from lenstronomy.PointSource.Types.unlensed import Unlensed
                 self._point_source_list.append(PointSourceCached(Unlensed(), save_cache=save_cache))
             elif model == 'LENSED_POSITION':
-                from lenstronomy.PointSource.point_source_types import LensedPositions
+                from lenstronomy.PointSource.Types.lensed_position import LensedPositions
                 self._point_source_list.append(PointSourceCached(LensedPositions(lensModel, fixed_magnification=fixed_magnification_list[i],
                                                                additional_image=additional_images_list[i]), save_cache=save_cache))
             elif model == 'SOURCE_POSITION':
-                from lenstronomy.PointSource.point_source_types import SourcePositions
+                from lenstronomy.PointSource.Types.source_position import SourcePositions
                 self._point_source_list.append(PointSourceCached(SourcePositions(lensModel,
                                                                  fixed_magnification=fixed_magnification_list[i]),
                                                                  save_cache=save_cache))
@@ -78,7 +79,7 @@ class PointSource(object):
         :param only_from_unspecified: bool, if True, only sets keywords that previously have not been set
         :return: updated self instances
         """
-        if min_distance is not None and not (hasattr(self._kwargs_lens_eqn_solver, 'min_distance') and only_from_unspecified):
+        if min_distance is not None and not 'min_distance' in self._kwargs_lens_eqn_solver and only_from_unspecified:
             self._kwargs_lens_eqn_solver['min_distance'] = min_distance
         if only_from_unspecified:
             self._kwargs_lens_eqn_solver['search_window'] = self._kwargs_lens_eqn_solver.get('search_window', search_window)
@@ -104,7 +105,7 @@ class PointSource(object):
         """
         deletes the variables saved for a specific lens model
 
-        :return:
+        :return: None
         """
         for model in self._point_source_list:
             model.delete_lens_model_cache()
@@ -113,7 +114,7 @@ class PointSource(object):
         """
         set the save cache boolean to new value
 
-        :param bool: bool
+        :param bool: bool, if True, saves (or uses a previously saved) values
         :return: updated class and sub-class instances to either save or not save the point source information in cache
         """
         self._set_save_cache(bool)
@@ -121,21 +122,22 @@ class PointSource(object):
 
     def _set_save_cache(self, bool):
         """
-        set the save cache boolean to new value. This function is for use within this class for temporarily set the cache within a single routine.
+        set the save cache boolean to new value. This function is for use within this class for temporarily set the
+        cache within a single routine.
 
-        :param bool:
-        :return:
+        :param bool: bool, if True, saves (or uses a previously saved) values
+        :return: None
         """
         for model in self._point_source_list:
             model.set_save_cache(bool)
 
     def source_position(self, kwargs_ps, kwargs_lens):
         """
+        intrinsic source positions of the point sources
 
-        :param kwargs_ps:
-        :param kwargs_lens:
-        :param recompute:
-        :return:
+        :param kwargs_ps: keyword argument list of point source models
+        :param kwargs_lens: keyword argument list of lens models
+        :return: list of source positions for each point source model
         """
         x_source_list = []
         y_source_list = []
@@ -148,6 +150,7 @@ class PointSource(object):
 
     def image_position(self, kwargs_ps, kwargs_lens, k=None, original_position=False):
         """
+        image positions as observed on the sky of the point sources
 
         :param kwargs_ps: point source parameter keyword argument list
         :param kwargs_lens: lens model keyword argument list
@@ -181,16 +184,18 @@ class PointSource(object):
         :param k: None, int or list of int's to select a subset of the point source models in the return
         :param with_amp: bool, if False, ignores the amplitude parameters in the return and instead provides ones for
          each point source image
-        :return: a_array, dec_array, amp_array
+        :return: ra_array, dec_array, amp_array
         """
+        # here we save the cache of the individual models but do not overwrite the class boolean variable to do so
         self._set_save_cache(True)
-        # we make sure we do not re-compute the image positions twice when evaluating image position and their amplitudes
+        # we make sure we do not re-compute the image positions twice when evaluating position and their amplitudes
         ra_list, dec_list = self.image_position(kwargs_ps, kwargs_lens, k=k)
         if with_amp is True:
             amp_list = self.image_amplitude(kwargs_ps, kwargs_lens, k=k)
         else:
             amp_list = np.ones_like(ra_list)
 
+        # here we delete the individual modeling caches in case this was the option
         if self._save_cache is False:
             self.delete_lens_model_cache()
             self._set_save_cache(self._save_cache)
@@ -204,6 +209,13 @@ class PointSource(object):
         return ra_array, dec_array, amp_array
 
     def num_basis(self, kwargs_ps, kwargs_lens):
+        """
+        number of basis functions for linear inversion
+
+        :param kwargs_ps: point source keyword argument list
+        :param kwargs_lens: lens model keyword argument list
+        :return: int
+        """
         n = 0
         ra_pos_list, dec_pos_list = self.image_position(kwargs_ps, kwargs_lens)
         for i, model in enumerate(self.point_source_type_list):
@@ -218,8 +230,9 @@ class PointSource(object):
         """
         returns the image amplitudes
 
-        :param kwargs_ps:
-        :param kwargs_lens:
+        :param kwargs_ps: point source keyword argument list
+        :param kwargs_lens: lens model keyword argument list
+        :param k: None, int or list of int's to select a subset of the point source models in the return
         :return: list of image amplitudes per model component
         """
         amp_list = []
@@ -231,11 +244,11 @@ class PointSource(object):
 
     def source_amplitude(self, kwargs_ps, kwargs_lens):
         """
-        returns the source amplitudes
+        intrinsic (unlensed) point source amplitudes
 
-        :param kwargs_ps:
-        :param kwargs_lens:
-        :return:
+        :param kwargs_ps: point source keyword argument list
+        :param kwargs_lens: lens model keyword argument list
+        :return: list of intrinsic (unlensed) point source amplitudes
         """
         amp_list = []
         for i, model in enumerate(self._point_source_list):
@@ -288,11 +301,11 @@ class PointSource(object):
     def update_linear(self, param, i, kwargs_ps, kwargs_lens):
         """
 
-        :param param:
-        :param i:
-        :param kwargs_ps:
-        :param kwargs_lens:
-        :return:
+        :param param: list of floats corresponding ot the parameters being sampled
+        :param i: index of the first parameter relevant for this class
+        :param kwargs_ps: point source keyword argument list
+        :param kwargs_lens: lens model keyword argument list
+        :return: kwargs_ps with updated linear parameters, index of the next parameter relevant for another class
         """
         ra_pos_list, dec_pos_list = self.image_position(kwargs_ps, kwargs_lens)
         for k, model in enumerate(self._point_source_list):
@@ -303,7 +316,7 @@ class PointSource(object):
                     i += 1
                 else:
                     n_points = len(ra_pos_list[k])
-                    kwargs['point_amp'] = param[i:i + n_points]
+                    kwargs['point_amp'] = np.array(param[i:i + n_points])
                     i += n_points
         return kwargs_ps, i
 
@@ -312,13 +325,13 @@ class PointSource(object):
         checks whether the point sources in kwargs_ps satisfy the lens equation with a tolerance
         (computed by ray-tracing in the source plane)
 
-        :param kwargs_ps:
-        :param kwargs_lens:
-        :param tolerance:
+        :param kwargs_ps: point source keyword argument list
+        :param kwargs_lens: lens model keyword argument list
+        :param tolerance: Eucledian distance between the source positions ray-traced backwards to be tolerated
         :return: bool: True, if requirement on tolerance is fulfilled, False if not.
         """
         x_image_list, y_image_list = self.image_position(kwargs_ps, kwargs_lens)
-        for i, model in enumerate(self._point_source_list):
+        for i, model in enumerate(self.point_source_type_list):
             if model in ['LENSED_POSITION', 'SOURCE_POSITION']:
                 x_pos = x_image_list[i]
                 y_pos = y_image_list[i]
@@ -330,6 +343,8 @@ class PointSource(object):
 
     def set_amplitudes(self, amp_list, kwargs_ps):
         """
+        translates the amplitude parameters into the convention of the keyword argument list
+        currently only used in SimAPI to transform magnitudes to amplitudes in the lenstronomy conventions
 
         :param amp_list: list of model amplitudes for each point source model
         :param kwargs_ps: list of point source keywords
@@ -353,14 +368,19 @@ class PointSource(object):
         """
         check whether inferred linear parameters are positive
 
-        :param kwargs_ps:
-        :return: bool
+        :param kwargs_ps: point source keyword argument list
+        :return: bool, True, if all 'point_amp' parameters are positive semi-definite
         """
         pos_bool = True
         for kwargs in kwargs_ps:
-            point_amp = kwargs['point_amp']
-            for amp in point_amp:
-                if amp < 0:
+            if 'point_amp' in kwargs:
+                point_amp = kwargs['point_amp']
+                if not np.all(point_amp >= 0):
+                    pos_bool = False
+                    break
+            if 'source_amp' in kwargs:
+                point_amp = kwargs['source_amp']
+                if not np.all(point_amp >= 0):
                     pos_bool = False
                     break
         return pos_bool
