@@ -345,23 +345,12 @@ class FittingSequence(object):
                   logZ, logZ_err, results_object]
         return output
 
-    def psf_iteration(self, num_iter=10, no_break=True, stacking_method='median', block_center_neighbour=0,
-                      keep_psf_error_map=True, psf_symmetry=1, psf_iter_factor=1, error_map_radius=None, verbose=True,
-                      compute_bands=None):
+    def psf_iteration(self, compute_bands=None, **kwargs_psf_iter):
         """
         iterative PSF reconstruction
 
-        :param num_iter: number of iterations in the process
-        :param no_break: bool, if False will break the process as soon as one step lead to a wors reconstruction then the previous step
-        :param stacking_method: string, 'median' and 'mean' supported
-        :param block_center_neighbour: radius of neighbouring point source to be blocked in the reconstruction
-        :param keep_psf_error_map: bool, whether or not to keep the previous psf_error_map
-        :param psf_symmetry: int, number of invariant rotations in the reconstructed PSF
-        :param psf_iter_factor: factor of new estimated PSF relative to the old one PSF_updated = (1-psf_iter_factor) * PSF_old + psf_iter_factor*PSF_new
-        :param error_map_radius: float, radius (in arc seconds) of the outermost error in the PSF estimate
-         (e.g. to avoid double counting of overlapping PSF errors)
-        :param verbose: bool, print statements
         :param compute_bands: bool list, if multiple bands, this process can be limited to a subset of bands
+        :param kwargs_psf_iter: keyword arguments as used or available in PSFIteration.update_iterative() definition
         :return: 0, updated PSF is stored in self.multi_band_list
         """
         kwargs_model = self._updateManager.kwargs_model
@@ -379,12 +368,7 @@ class FittingSequence(object):
                                                    likelihood_mask_list=likelihood_mask_list, band_index=band_index,
                                                    kwargs_pixelbased=kwargs_pixelbased)
                 psf_iter = PsfFitting(image_model_class=image_model)
-                kwargs_psf = psf_iter.update_iterative(kwargs_psf, kwargs_params=kwargs_temp, num_iter=num_iter,
-                                                       no_break=no_break, stacking_method=stacking_method,
-                                                       block_center_neighbour=block_center_neighbour,
-                                                       keep_psf_error_map=keep_psf_error_map, psf_symmetry=psf_symmetry,
-                                                       psf_iter_factor=psf_iter_factor,
-                                                       error_map_radius=error_map_radius, verbose=verbose)
+                kwargs_psf = psf_iter.update_iterative(kwargs_psf, kwargs_params=kwargs_temp, **kwargs_psf_iter)
                 self.multi_band_list[band_index][1] = kwargs_psf
         return 0
 
