@@ -23,3 +23,7 @@ class TestRaise(unittest.TestCase):
             base.derivatives()
         with self.assertRaises(ValueError):
             base.hessian()
+        with self.assertRaises(ValueError):
+            base.density_lens()
+        with self.assertRaises(ValueError):
+            base.mass_3d_lens()
