@@ -54,10 +54,11 @@ class TestHernquist(object):
         y = np.array([2])
         Rs = 1.
         sigma0 = 0.5
-        f_xx, f_yy,f_xy = self.profile.hessian(x, y, sigma0, Rs)
+        f_xx, f_xy, f_yx, f_yy = self.profile.hessian(x, y, sigma0, Rs)
         npt.assert_almost_equal(f_xx[0], 0.0779016004481825, decimal=6)
         npt.assert_almost_equal(f_yy[0], -0.023212809452388683, decimal=6)
         npt.assert_almost_equal(f_xy[0], -0.0674096084507525, decimal=6)
+        npt.assert_almost_equal(f_xy, f_yx, decimal=8)
 
     def test_mass_tot(self):
         rho0 = 1
@@ -131,10 +132,11 @@ class TestHernquistEllipse(object):
         sigma0 = 0.5
         q, phi_G = 0.8, 0.5
         e1, e2 = param_util.phi_q2_ellipticity(phi_G, q)
-        f_xx, f_yy,f_xy = self.profile.hessian(x, y, sigma0, Rs, e1, e2)
+        f_xx, f_xy, f_yx, f_yy = self.profile.hessian(x, y, sigma0, Rs, e1, e2)
         npt.assert_almost_equal(f_xx[0], 0.09340916928834986, decimal=6)
         npt.assert_almost_equal(f_yy[0], -0.02853883795950196, decimal=6)
         npt.assert_almost_equal(f_xy[0], -0.06298489507727822, decimal=6)
+        npt.assert_almost_equal(f_xy, f_yx, decimal=6)
 
 
 if __name__ == '__main__':
