@@ -6,7 +6,8 @@ import pytest
 from lenstronomy.LensModel.lens_model_extensions import LensModelExtensions
 from lenstronomy.LensModel.Solver.lens_equation_solver import LensEquationSolver
 from lenstronomy.LensModel.lens_model import LensModel
-from lenstronomy.LensModel.Profiles.curved_arc import CurvedArc
+from lenstronomy.LensModel.Profiles.curved_arc_spp import CurvedArcSPP
+from lenstronomy.LensModel.Profiles.curved_arc_tan_diff import CurvedArcTanDiff
 from lenstronomy.Util import util
 
 
@@ -18,7 +19,7 @@ class TestArcDistortions(object):
         pass
 
     def test_radial_tangential_distortions(self):
-        lens_model_list = ['CURVED_ARC', 'SHEAR', 'FLEXION']
+        lens_model_list = ['CURVED_ARC_SPP', 'SHEAR', 'FLEXION']
         center_x, center_y = 0.01, 0
         curvature = 1./2
         lens = LensModel(lens_model_list=lens_model_list)
@@ -136,14 +137,14 @@ class TestArcDistortions(object):
     def test_curved_arc_estimate(self):
         lens_model_list = ['SPP']
         lens = LensModel(lens_model_list=lens_model_list)
-        arc = LensModel(lens_model_list=['CURVED_ARC'])
+        arc = LensModel(lens_model_list=['CURVED_ARC_SPP'])
         theta_E = 4
         gamma = 2.
         kwargs_lens = [{'theta_E': theta_E, 'gamma': gamma, 'center_x': 0, 'center_y': 0}]
         ext = LensModelExtensions(lensModel=lens)
         x_0, y_0 = 5, 0
         kwargs_arc = ext.curved_arc_estimate(x_0, y_0, kwargs_lens)
-        theta_E_arc, gamma_arc, center_x_spp_arc, center_y_spp_arc = CurvedArc.stretch2spp(**kwargs_arc)
+        theta_E_arc, gamma_arc, center_x_spp_arc, center_y_spp_arc = CurvedArcSPP.stretch2spp(**kwargs_arc)
         npt.assert_almost_equal(theta_E_arc, theta_E, decimal=4)
         npt.assert_almost_equal(gamma_arc, gamma, decimal=3)
         npt.assert_almost_equal(center_x_spp_arc, 0, decimal=3)
@@ -157,7 +158,7 @@ class TestArcDistortions(object):
 
         x_0, y_0 = 0., 3
         kwargs_arc = ext.curved_arc_estimate(x_0, y_0, kwargs_lens)
-        theta_E_arc, gamma_arc, center_x_spp_arc, center_y_spp_arc = CurvedArc.stretch2spp(**kwargs_arc)
+        theta_E_arc, gamma_arc, center_x_spp_arc, center_y_spp_arc = CurvedArcSPP.stretch2spp(**kwargs_arc)
         print(kwargs_arc)
         print(theta_E_arc, gamma_arc, center_x_spp_arc, center_y_spp_arc)
         npt.assert_almost_equal(theta_E_arc, theta_E, decimal=4)
@@ -167,12 +168,43 @@ class TestArcDistortions(object):
 
         x_0, y_0 = -2, -3
         kwargs_arc = ext.curved_arc_estimate(x_0, y_0, kwargs_lens)
-        theta_E_arc, gamma_arc, center_x_spp_arc, center_y_spp_arc = CurvedArc.stretch2spp(**kwargs_arc)
+        theta_E_arc, gamma_arc, center_x_spp_arc, center_y_spp_arc = CurvedArcSPP.stretch2spp(**kwargs_arc)
         npt.assert_almost_equal(theta_E_arc, theta_E, decimal=4)
         npt.assert_almost_equal(gamma_arc, gamma, decimal=3)
         npt.assert_almost_equal(center_x_spp_arc, 0, decimal=3)
         npt.assert_almost_equal(center_y_spp_arc, 0, decimal=3)
 
+    def test_curved_arc_estimate_tan_diff(self):
+        lens_model_list = ['SIE']
+        lens = LensModel(lens_model_list=lens_model_list)
+        arc = LensModel(lens_model_list=['CURVED_ARC_TAN_DIFF'])
+        theta_E = 4
+        e1, e2 = 0, -0.1
+        kwargs_lens = [{'theta_E': theta_E, 'e1': e1, 'e2': e2, 'center_x': 0, 'center_y': 0}]
+        ext = LensModelExtensions(lensModel=lens)
+        x_0, y_0 = 5, 0.01
+        kwargs_arc = ext.curved_arc_estimate(x_0, y_0, kwargs_lens, tan_diff=True, smoothing_3rd=0.001)
+
+        x, y = util.make_grid(numPix=100, deltapix=0.1)
+        kappa = lens.kappa(x, y, kwargs_lens)
+        kappa_arc = arc.kappa(x, y, [kwargs_arc])
+
+        #import matplotlib.pyplot as plt
+        #plt.matshow(util.array2image(np.log10(kappa_arc)))
+        #plt.show()
+
+        #plt.matshow(util.array2image(np.log10(kappa)))
+        #plt.show()
+
+        arc_tan_diff = CurvedArcTanDiff()
+
+        theta_E_sie, e1_sie, e2_sie, kappa_ext, center_x_sis, center_y_sis = arc_tan_diff.stretch2sie_mst(**kwargs_arc)
+        print(theta_E_sie, e1_sie, e2_sie, center_x_sis, center_y_sis)
+        #TODO this test is relatively imprecise, this may have to do with the inaccuracies of the finite second order differentials
+        npt.assert_almost_equal(e1_sie, e1, decimal=1)
+
+        #npt.assert_almost_equal(kappa_arc, kappa, decimal=1)
+
     def test_arcs_at_image_position(self):
         # lensing quantities
         kwargs_spp = {'theta_E': 1.26, 'gamma': 2., 'e1': 0.1, 'e2': -0.1, 'center_x': 0.0, 'center_y': 0.0}  # parameters of the deflector lens model
@@ -186,7 +218,7 @@ class TestArcDistortions(object):
         source_y = 0.05
         x_image, y_image = lensEquationSolver.findBrightImage(source_x, source_y, kwargs_lens, numImages=4,
                                                               min_distance=0.05, search_window=5)
-        arc_model = LensModel(lens_model_list=['CURVED_ARC', 'SHIFT'])
+        arc_model = LensModel(lens_model_list=['CURVED_ARC_SPP', 'SHIFT'])
         for i in range(len(x_image)):
             x0, y0 = x_image[i], y_image[i]
             print(x0, y0, i)
@@ -205,7 +237,7 @@ class TestArcDistortions(object):
             print(gamma1, gamma2)
             npt.assert_almost_equal(gamma1_arc, gamma1, decimal=3)
             npt.assert_almost_equal(gamma2_arc, gamma2, decimal=3)
-            theta_E_arc, gamma_arc, center_x_spp_arc, center_y_spp_arc = CurvedArc.stretch2spp(**kwargs_arc_i)
+            theta_E_arc, gamma_arc, center_x_spp_arc, center_y_spp_arc = CurvedArcSPP.stretch2spp(**kwargs_arc_i)
             print(theta_E_arc, gamma_arc, center_x_spp_arc, center_y_spp_arc)
             npt.assert_almost_equal(center_x_spp_arc, 0, decimal=3)
             npt.assert_almost_equal(center_y_spp_arc, 0, decimal=3)
