@@ -51,7 +51,7 @@ class TestNumerics(object):
         int_profile = ProfileIntegrals(lensModel)
         r = 2.
         kappa_num = int_profile.density_2d(r, kwargs, lens_param=True)
-        f_xx, f_yy, f_xy = lensModel.hessian(r, 0, **kwargs)
+        f_xx, f_xy, f_yx, f_yy = lensModel.hessian(r, 0, **kwargs)
         kappa = 1./2 * (f_xx + f_yy)
         npt.assert_almost_equal(kappa_num, kappa, decimal=2)
         if hasattr(lensModel, 'mass_2d_lens'):
@@ -301,6 +301,36 @@ class TestNumerics(object):
         self.assert_integrals(Model, kwargs)
         self.assert_lens_integrals(Model, kwargs)
 
+    def test_cored_density_exp(self):
+        from lenstronomy.LensModel.Profiles.cored_density_exp import CoredDensityExp as Model
+        kwargs = {'kappa_0': 0.1, 'theta_c': 6.}
+        self.assert_integrals(Model, kwargs)
+        self.assert_lens_integrals(Model, kwargs)
+
+    def test_uldm(self):
+        from lenstronomy.LensModel.Profiles.uldm import Uldm as Model
+        kwargs = {'kappa_0': 0.1, 'theta_c': 6.}
+        self.assert_integrals(Model, kwargs)
+        self.assert_lens_integrals(Model, kwargs)
+
+    def test_splcore(self):
+
+        from lenstronomy.LensModel.Profiles.splcore import SPLCORE as Model
+        kwargs = {'rho0': 1., 'gamma': 3, 'r_core': 0.1}
+        self.assert_integrals(Model, kwargs)
+        kwargs = {'sigma0': 1., 'gamma': 3, 'r_core': 0.1}
+        self.assert_lens_integrals(Model, kwargs)
+
+        kwargs = {'rho0': 1., 'gamma': 2, 'r_core': 0.1}
+        self.assert_integrals(Model, kwargs)
+        kwargs = {'sigma0': 1., 'gamma': 2, 'r_core': 0.1}
+        self.assert_lens_integrals(Model, kwargs)
+
+        kwargs = {'rho0': 1., 'gamma': 2.5, 'r_core': 0.1}
+        self.assert_integrals(Model, kwargs)
+        kwargs = {'sigma0': 1., 'gamma': 2.5, 'r_core': 0.1}
+        self.assert_lens_integrals(Model, kwargs)
+
 
     """
     def test_sis(self):
